summaryrefslogtreecommitdiffstats
path: root/klinkstatus
diff options
context:
space:
mode:
Diffstat (limited to 'klinkstatus')
-rw-r--r--klinkstatus/src/engine/searchmanager.cpp6
-rw-r--r--klinkstatus/src/global.cpp8
-rw-r--r--klinkstatus/src/klinkstatus.cpp8
-rw-r--r--klinkstatus/src/ui/tablelinkstatus.cpp6
-rw-r--r--klinkstatus/src/ui/treeview.cpp6
-rw-r--r--klinkstatus/src/utils/xsl.cpp2
6 files changed, 18 insertions, 18 deletions
diff --git a/klinkstatus/src/engine/searchmanager.cpp b/klinkstatus/src/engine/searchmanager.cpp
index e05087d1..6e4f656a 100644
--- a/klinkstatus/src/engine/searchmanager.cpp
+++ b/klinkstatus/src/engine/searchmanager.cpp
@@ -314,7 +314,7 @@ vector<LinkStatus*> SearchManager::children(LinkStatus* link)
}
if(count == 50)
{
- kapp->processEvents();
+ tdeApp->processEvents();
count = 0;
}
}
@@ -374,7 +374,7 @@ LinkStatus const* SearchManager::linkStatus(TQString const& s_url) const
if(count == 50)
{
count = 0;
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
@@ -599,7 +599,7 @@ void SearchManager::addLevel()
}
emit signalAddingLevelProgress();
-// kapp->processEvents();
+// tdeApp->processEvents();
}
}
if( (search_results_[search_results_.size() - 1]).size() == 0 )
diff --git a/klinkstatus/src/global.cpp b/klinkstatus/src/global.cpp
index 4103056f..f214a85b 100644
--- a/klinkstatus/src/global.cpp
+++ b/klinkstatus/src/global.cpp
@@ -44,7 +44,7 @@ Global::Global(TQObject *parent, const char *name)
: TQObject(parent, name), loop_started_(false)
{
m_self_ = this;
- dcop_client_ = kapp->dcopClient();
+ dcop_client_ = tdeApp->dcopClient();
}
Global::~Global()
@@ -89,7 +89,7 @@ bool Global::isQuantaAvailableViaDCOP()
TQCString Global::quantaDCOPAppId()
{
- DCOPClient* client = kapp->dcopClient();
+ DCOPClient* client = tdeApp->dcopClient();
TQCString app_id;
if(client->isApplicationRegistered("quanta")) // quanta is unnique application
@@ -168,7 +168,7 @@ void Global::execCommand(TQString const& command)
self(), TQ_SLOT(slotProcessTimeout()));
timer->start(120*1000, true);
self()->loop_started_ = true;
- kapp->enter_loop();
+ tdeApp->enter_loop();
delete timer;
}
}
@@ -196,7 +196,7 @@ void Global::slotProcessTimeout()
{
if (loop_started_)
{
- kapp->exit_loop();
+ tdeApp->exit_loop();
loop_started_ = false;
}
}
diff --git a/klinkstatus/src/ui/tablelinkstatus.cpp b/klinkstatus/src/ui/tablelinkstatus.cpp
index 28ac2aa0..de8d2f38 100644
--- a/klinkstatus/src/ui/tablelinkstatus.cpp
+++ b/klinkstatus/src/ui/tablelinkstatus.cpp
@@ -314,7 +314,7 @@ void TableLinkstatus::slotCopyUrlToClipboard() const
{
TableItem* _item = myItem(currentRow(), currentColumn());
TQString content(_item->linkStatus()->absoluteUrl().prettyURL());
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(content);
}
@@ -322,14 +322,14 @@ void TableLinkstatus::slotCopyParentUrlToClipboard() const
{
TableItem* _item = myItem(currentRow(), currentColumn());
TQString content(_item->linkStatus()->parent()->absoluteUrl().prettyURL());
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(content);
}
void TableLinkstatus::slotCopyCellTextToClipboard() const
{
TQString cell_text(text(currentRow(), currentColumn()));
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(cell_text);
}
diff --git a/klinkstatus/src/ui/treeview.cpp b/klinkstatus/src/ui/treeview.cpp
index c0cebe68..1ce7d009 100644
--- a/klinkstatus/src/ui/treeview.cpp
+++ b/klinkstatus/src/ui/treeview.cpp
@@ -219,7 +219,7 @@ void TreeView::slotCopyUrlToClipboard() const
{
TreeViewItem* _item = myItem(currentItem());
TQString content(_item->linkStatus()->absoluteUrl().prettyURL());
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(content);
}
@@ -227,7 +227,7 @@ void TreeView::slotCopyParentUrlToClipboard() const
{
TreeViewItem* _item = myItem(currentItem());
TQString content(_item->linkStatus()->parent()->absoluteUrl().prettyURL());
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(content);
}
@@ -235,7 +235,7 @@ void TreeView::slotCopyCellTextToClipboard() const
{
TreeViewItem* _item = myItem(currentItem());
TQString cell_text(_item->text(current_column_));
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = tdeApp->clipboard();
cb->setText(cell_text);
}
diff --git a/klinkstatus/src/utils/xsl.cpp b/klinkstatus/src/utils/xsl.cpp
index 69366c5f..8ec1352f 100644
--- a/klinkstatus/src/utils/xsl.cpp
+++ b/klinkstatus/src/utils/xsl.cpp
@@ -141,7 +141,7 @@ TQString KopeteXSLThread::xsltTransform( const TQString &xmlString, xsltStyleshe
{
if ( styleSheet )
{
- static TQCString appPath( TQString::fromLatin1("\"%1\"").arg( TDEApplication::kApplication()->dirs()->findDirs("appdata", TQString::fromLatin1("styles/data") ).front() ).utf8() );
+ static TQCString appPath( TQString::fromLatin1("\"%1\"").arg( tdeApp->dirs()->findDirs("appdata", TQString::fromLatin1("styles/data") ).front() ).utf8() );
static const char* params[3] = {
"appdata",
diff --git a/klinkstatus/src/klinkstatus.cpp b/klinkstatus/src/klinkstatus.cpp
index 7a125bb5..be1d4b0e 100644
--- a/klinkstatus/src/klinkstatus.cpp
+++ b/klinkstatus/src/klinkstatus.cpp
@@ -73,8 +73,8 @@ KLinkStatus::KLinkStatus()
// if we couldn't find our Part, we exit since the Shell by
// itself can't do anything useful
KMessageBox::error(this, i18n("Could not find the KLinkStatus part; did you configure with '--prefix=/$TDEDIR' and perform 'make install'?"));
- kapp->quit();
- // we return here, cause kapp->quit() only means "exit the
+ tdeApp->quit();
+ // we return here, cause tdeApp->quit() only means "exit the
// next time we enter the event loop...
return;
}
@@ -97,13 +97,13 @@ void KLinkStatus::load(const KURL& url)
void KLinkStatus::setupActions()
{
- // KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
+ // KStdAction::quit(tdeApp, TQ_SLOT(quit()), actionCollection());
// The above causes a segfault when using File->Quit.
// Here's Waldo's explanation:
/* I had a look. The problem is due to the SessionWidget destructor calling
KLSConfig. If you use the window button, the window and the SessionWidget is
destructed first and then later the application is destructed.
- If you use File->Quit it calls kapp->quit which destructs the application
+ If you use File->Quit it calls tdeApp->quit which destructs the application
without destructing the window first. The application first destructs all
static deleters and its administration, and then goes on to kill the
remaining windows that it owns. Therein lies the problem because by then the